@@ -3,10 +3,8 @@ import sys
 from bugsnag.configuration import Configuration, RequestConfiguration
 from bugsnag.notification import Notification
 
-
 configuration = Configuration()
 
-
 def configure(**options):
     """
     Configure the Bugsnag notifier application-wide settings.
@@ -52,12 +50,19 @@ def auto_notify(exception, **options):
     if configuration.auto_notify:
         notify(exception, severity="error", **options)
 
+def before_notify(callback):
+    """
+    Add a callback to be called before bugsnag is notified
+
+    This can be used to alter the notification before sending it to Bugsnag.
+    """
+    configuration.middleware.before_notify(callback)
 
 def log(message):
     """
     Print a log message with a Bugsnag prefix.
     """
-    print("** [Bugsnag] %s" % message)
+    print(("** [Bugsnag] %s" % message))
 
 
 def warn(message):
